@@ -1,18 +1,18 @@
-# Copyright 2020 Q-CTRL Pty Ltd & Q-CTRL Inc. All rights reserved.
+# Copyright 2021 Q-CTRL. All rights reserved.
 #
 # Licensed under the Q-CTRL Terms of service (the "License"). Unauthorized
 # copying or use of this file, via any medium, is strictly prohibited.
 # Proprietary and confidential. You may not use this file except in compliance
 # with the License. You may obtain a copy of the License at
 #
-#     https://q-ctrl.com/terms
+#    https://q-ctrl.com/terms
 #
 # Unless required by applicable law or agreed to in writing, software
 # distributed under the License is distributed on an "AS IS" BASIS. See the
 # License for the specific language.
 
 """
-Controller for integration of BOULDER OPAL automated closed-loop optimizers and M-LOOP.
+Controller for integration of Boulder Opal automated closed-loop optimizers and M-LOOP.
 """
 import re
 from typing import (
@@ -34,13 +34,13 @@ from qctrlcommons.preconditions import check_argument
 
 class QctrlController(Controller):
     """
-    Controller for optimizations that uses BOULDER OPAL automated
+    Controller for optimizations that uses Boulder Opal automated
     closed-loop optimizers.
 
     You can use this controller to integrate an experiment managed by
-    M-LOOP to a BOULDER OPAL automated closed-loop optimizer. Notice that
+    M-LOOP to a Boulder Opal automated closed-loop optimizer. Notice that
     you need to set up an M-LOOP Interface to your experiment, initiate a
-    BOULDER OPAL session, and define your choice of BOULDER OPAL automated
+    Boulder Opal session, and define your choice of Boulder Opal automated
     closed-loop optimizer prior to using this class.
 
     Arguments
@@ -49,33 +49,33 @@ class QctrlController(Controller):
         The M-LOOP interface from where you obtain the cost value of the
         test points.
     qctrl : qctrl.Qctrl
-        The object representing the BOULDER OPAL session. You must initiate
+        The object representing the Boulder Opal session. You must initiate
         it before calling the controller.
     optimizer : qctrl.types.closed_loop_optimization_step.Optimizer
-        The BOULDER OPAL automated closed-loop optimizer that you want to
+        The Boulder Opal automated closed-loop optimizer that you want to
         use. It must be a valid optimizer object (containing either an
         initializer or a state from a previous optimization run), as
-        described in the BOULDER OPAL reference documentation.
+        described in the Boulder Opal reference documentation.
     test_point_count : int, optional
-        The requested number of test points that the BOULDER OPAL automated
+        The requested number of test points that the Boulder Opal automated
         closed-loop optimizer generates at each step. If chosen, it must be
-        greater than zero. This is a hint only. The BOULDER OPAL automated
+        greater than zero. This is a hint only. The Boulder Opal automated
         closed-loop optimizer might choose differently.
     learner : mloop.learners.Learner, optional
         The M-LOOP Learner that this controller uses to obtain extra test
         points, before there are enough results to run a step of the
-        BOULDER OPAL automated closed-loop optimizer. Defaults to None, in
+        Boulder Opal automated closed-loop optimizer. Defaults to None, in
         which case this controller uses a `RandomLearner`.
     training_run_count : int, optional
         The minimum number of training points that the controller obtains
-        before calling the BOULDER OPAL automated closed-loop optimizer.
+        before calling the Boulder Opal automated closed-loop optimizer.
         Defaults to 0, in which case the controller uses the minimum number
-        of points that the BOULDER OPAL automated closed-loop optimizer
+        of points that the Boulder Opal automated closed-loop optimizer
         requires.
     interleaved_run_count : int, optional
         The minimum number of test points that the controller obtains from
-        the `learner` between two calls of the BOULDER OPAL automated
-        closed-loop optimizer, in addition to the points that BOULDER OPAL
+        the `learner` between two calls of the Boulder Opal automated
+        closed-loop optimizer, in addition to the points that Boulder Opal
         requested. Defaults to 0.
     kwargs : dict
         All the extra arguments that the Controller class from M-LOOP
@@ -96,7 +96,7 @@ class QctrlController(Controller):
         super().__init__(interface, **kwargs)
 
         # Auxiliary learner, used to get the initial test points before
-        # there are enough points to run BOULDER OPAL automated closed-loop
+        # there are enough points to run Boulder Opal automated closed-loop
         # optimization.
         self.learner = learner
         if self.learner is None:
@@ -147,7 +147,7 @@ class QctrlController(Controller):
 
     def _call_boulder_opal(self, cost_function_results: List[Any]) -> List[np.ndarray]:
         """
-        Manages each call to BOULDER OPAL.
+        Manages each call to Boulder Opal.
         """
         result = self._optimization_step(
             optimizer=self._optimizer,
@@ -184,7 +184,7 @@ class QctrlController(Controller):
         required_run_count = self._training_run_count
 
         while self.check_end_conditions():
-            # Call BOULDER OPAL only if the number of required runs has
+            # Call Boulder Opal only if the number of required runs has
             # been reached and there is at least one result to pass.
             if (self.num_in_costs >= required_run_count) and (
                 len(cost_function_results) > 0
@@ -193,7 +193,7 @@ class QctrlController(Controller):
                 cost_function_results = []
                 # The total number of runs before the next call to BOULDER
                 # OPAL, which is: the current number of runs, plus the
-                # number of runs that BOULDER OPAL requested, plus the
+                # number of runs that Boulder Opal requested, plus the
                 # number of extra interleaved runs that the auxiliary
                 # learner requests.
                 required_run_count = (
@@ -202,12 +202,12 @@ class QctrlController(Controller):
                     + self._interleaved_run_count
                 )
 
-            # Obtain parameters from the BOULDER OPAL automated closed-loop
+            # Obtain parameters from the Boulder Opal automated closed-loop
             # optimizer if any are available.
             use_boulder_opal_parameters = len(boulder_opal_parameters) > 0
             if use_boulder_opal_parameters:
                 parameters = boulder_opal_parameters.pop(0)
-            # Use auxiliary learner if the BOULDER OPAL automated
+            # Use auxiliary learner if the Boulder Opal automated
             # closed-loop optimizer doesn't have more parameters to suggest.
             else:
                 parameters = self.learner_params_queue.get()
@@ -231,7 +231,7 @@ class QctrlController(Controller):
                     )
                 )
 
-            # Store cost function result in the list to be used by BOULDER OPAL.
+            # Store cost function result in the list to be used by Boulder Opal.
             if not self.curr_bad:
                 cost_function_results.append(
                     self._types_namespace.CostFunctionResult(
@@ -278,28 +278,28 @@ def qctrl_controller(
         initializer with ``initializer_`` and include them in the keyword
         arguments of this function.
     api_root : str, optional
-        The URL of the BOULDER OPAL API that you want to use. Defaults to
+        The URL of the Boulder Opal API that you want to use. Defaults to
         ``None``, in which case the default API server is used.
     test_point_count : int, optional
-        The requested number of test points that the BOULDER OPAL automated
+        The requested number of test points that the Boulder Opal automated
         closed-loop optimizer generates at each step. If chosen, it must be
-        greater than zero. This is a hint only. The BOULDER OPAL automated
+        greater than zero. This is a hint only. The Boulder Opal automated
         closed-loop optimizer might choose differently.
     learner_name : str, optional
         The name of the M-LOOP Learner that this controller uses to obtain
         extra test points, before there are enough results to run a step of
-        the BOULDER OPAL automated closed-loop optimizer. Defaults to
+        the Boulder Opal automated closed-loop optimizer. Defaults to
         ``None``, in which case this controller uses a `RandomLearner`.
     training_run_count : int, optional
         The minimum number of training points that the controller obtains
-        before calling the BOULDER OPAL automated closed-loop optimizer.
+        before calling the Boulder Opal automated closed-loop optimizer.
         Defaults to 0, in which case the controller uses the minimum number
-        of points that the BOULDER OPAL automated closed-loop optimizer
+        of points that the Boulder Opal automated closed-loop optimizer
         requires.
     interleaved_run_count : int, optional
         The minimum number of test points that the controller obtains from
-        the learner between two calls of the BOULDER OPAL automated
-        closed-loop optimizer, in addition to the points that BOULDER OPAL
+        the learner between two calls of the Boulder Opal automated
+        closed-loop optimizer, in addition to the points that Boulder Opal
         requested. Defaults to 0.
     kwargs : dict
         All the extra arguments that the Controller class from M-LOOP
@@ -308,7 +308,7 @@ def qctrl_controller(
     Returns
     -------
     QctrlController
-        The controller that integrates BOULDER OPAL with M-LOOP.
+        The controller that integrates Boulder Opal with M-LOOP.
 
     Raises
     ------
